@@ -192,6 +192,8 @@ public final class NtlmPasswordAuthentication implements Principal, Serializable
     }
     public static byte[] nTOWFv1(String password)
     {
+        if (password == null)
+            throw new RuntimeException("Password parameter is required");
         try {
             MD4 md4 = new MD4();
             md4.update(password.getBytes(SmbConstants.UNI_ENCODING));
