@@ -92,7 +92,7 @@ public class SmbTransport extends Transport implements SmbConstants {
     int port, mid;
     OutputStream out;
     InputStream in;
-    byte[] sbuf = new byte[255]; /* small local buffer */
+    byte[] sbuf = new byte[512]; /* small local buffer */
     SmbComBlankResponse key = new SmbComBlankResponse();
     long sessionExpiration = System.currentTimeMillis() + SO_TIMEOUT;
     LinkedList referrals = new LinkedList();
@@ -181,12 +181,20 @@ public class SmbTransport extends Transport implements SmbConstants {
     void ssn139() throws IOException {
         Name calledName = new Name( address.firstCalledName(), 0x20, null );
         do {
+/* These Socket constructors attempt to connect before SO_TIMEOUT can be applied
             if (localAddr == null) {
                 socket = new Socket( address.getHostAddress(), 139 );
             } else {
                 socket = new Socket( address.getHostAddress(), 139, localAddr, localPort );
             }
             socket.setSoTimeout( SO_TIMEOUT );
+*/
+
+            socket = new Socket();
+            if (localAddr != null)
+                socket.bind(new InetSocketAddress(localAddr, localPort));
+            socket.connect(new InetSocketAddress(address.getHostAddress(), 139), SO_TIMEOUT);
+
             out = socket.getOutputStream();
             in = socket.getInputStream();
 
@@ -236,24 +244,24 @@ public class SmbTransport extends Transport implements SmbConstants {
          * until we have properly negotiated.
          */
         synchronized (sbuf) {
-            /* If jcifs.netbios.hostname is set this *probably* means there
-             * is a policy regarding which hosts a user can connect from. This
-             * requires communicating over port 139 rather than 445.
-             */
-            if (false && NETBIOS_HOSTNAME != null && NETBIOS_HOSTNAME.equals( "" ) == false) {
-                port = 139;
-            }
             if (port == 139) {
                 ssn139();
             } else {
                 if (port == 0)
                     port = DEFAULT_PORT; // 445
+/* These Socket constructors attempt to connect before SO_TIMEOUT can be applied
                 if (localAddr == null) {
                     socket = new Socket( address.getHostAddress(), port );
                 } else {
                     socket = new Socket( address.getHostAddress(), port, localAddr, localPort );
                 }
                 socket.setSoTimeout( SO_TIMEOUT );
+*/
+                socket = new Socket();
+                if (localAddr != null)
+                    socket.bind(new InetSocketAddress(localAddr, localPort));
+                socket.connect(new InetSocketAddress(address.getHostAddress(), port), SO_TIMEOUT);
+
                 out = socket.getOutputStream();
                 in = socket.getInputStream();
             }
@@ -351,15 +359,20 @@ public class SmbTransport extends Transport implements SmbConstants {
     }
     protected void doDisconnect( boolean hard ) throws IOException {
         ListIterator iter = sessions.listIterator();
-        while (iter.hasNext()) {
-            SmbSession ssn = (SmbSession)iter.next();
-            ssn.logoff( hard );
+        try {
+            while (iter.hasNext()) {
+                SmbSession ssn = (SmbSession)iter.next();
+                ssn.logoff( hard );
+            }
+            socket.shutdownOutput();
+            out.close();
+            in.close();
+            socket.close();
+        } finally {
+            digest = null;
+            socket = null;
+            tconHostName = null;
         }
-        socket.shutdownOutput();
-        out.close();
-        in.close();
-        socket.close();
-        digest = null;
     }
 
     protected void makeKey( Request request ) throws IOException {
@@ -432,6 +445,9 @@ public class SmbTransport extends Transport implements SmbConstants {
                     Hexdump.hexdump( log, BUF, 4, n );
                 }
             }
+            /* For some reason this can sometimes get broken up into another
+             * "NBSS Continuation Message" frame according to WireShark
+             */
             out.write( BUF, 0, 4 + n );
         }
     }
@@ -470,10 +486,13 @@ public class SmbTransport extends Transport implements SmbConstants {
                                     /* WordCount thru dataOffset always 27 */
                 readn( in, BUF, 4 + off, 27 ); off += 27;
                 resp.decode( BUF, 4 );
-                if (r.dataLength > 0) {
-                    readn( in, BUF, 4 + off, r.dataOffset - off);   /* pad */
+                                              /* EMC can send pad w/o data */
+                int pad = r.dataOffset - off;
+                if (r.byteCount > 0 && pad > 0 && pad < 4)
+                    readn( in, BUF, 4 + off, pad);
+
+                if (r.dataLength > 0)
                     readn( in, r.b, r.off, r.dataLength );  /* read direct */
-                }
             } else {
                 readn( in, BUF, 4 + 32, size - 32 );
                 resp.decode( BUF, 4 );
@@ -586,7 +605,7 @@ public class SmbTransport extends Transport implements SmbConstants {
                         makeKey( req );
                     }
 
-                    synchronized (response_map) {
+                    synchronized (this) {
                         response.received = false;
                         resp.isReceived = false;
                         try {
@@ -607,7 +626,7 @@ public class SmbTransport extends Transport implements SmbConstants {
                             long timeout = RESPONSE_TIMEOUT;
                             resp.expiration = System.currentTimeMillis() + timeout;
                             while( resp.hasMoreElements() ) {
-                                response_map.wait( timeout );
+                                wait( timeout );
                                 timeout = resp.expiration - System.currentTimeMillis();
                                 if (timeout <= 0) {
                                     throw new TransportException( this +
@@ -635,8 +654,6 @@ public class SmbTransport extends Transport implements SmbConstants {
             }
         } catch( SmbException se ) {
             throw se;
-        } catch( InterruptedException ie ) {
-            throw new SmbException( ie.getMessage(), ie );
         } catch( IOException ioe ) {
             throw new SmbException( ioe.getMessage(), ioe );
         }
